@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import sys
 from time import time
 from threading import Thread
 
@@ -37,6 +38,13 @@ class TimeoutError(RuntimeError):
     pass
 
 
+class ResponseError(object):
+    def __init__(self, status_code, body, error=None):
+        self.status_code = status_code
+        self.body = body
+        self.error = error
+
+
 class Octopus(object):
     def __init__(self, concurrency=10, auto_start=False, cache=False, expiration_in_seconds=30):
         self.concurrency = concurrency
@@ -82,7 +90,15 @@ class Octopus(object):
                 response = self.response_cache.get(url)
 
             if response is None:
-                response = requests.request(method, url, **kwargs)
+                try:
+                    response = requests.request(method, url, **kwargs)
+                except requests.ConnectionError:
+                    err = sys.exc_info()[1]
+                    response = ResponseError(
+                        status_code=500,
+                        body=str(err.message),
+                        error=err
+                    )
 
                 if self.cache:
                     self.response_cache.put(url, response)
